######
ut-arr
######

**Utilities for Arrays** — version |release|

.. contents:: Table of Contents
   :depth: 3
   :local:


.. include:: modules/overview.rst

.. include:: modules/installation.rst


*******
Logging
*******

Logging is provided by the classes ``ut_log.log.Log`` or ``ut_log.log.LogEq``.
See `ut_log on PyPI <https://pypi.org/project/ut_log/>`_ for configuration
keys, log levels and examples.


.. include:: modules/package_files.rst

.. include:: modules/package_modules.rst

.. include:: modules/arr.rst

.. include:: modules/ao2a.rst

.. include:: modules/aoa.rst

.. include:: modules/aod.rst

.. include:: modules/aoo.rst

.. include:: modules/aos.rst


********
See Also
********

.. table:: *Documents*

   +------------------+-------------------------------------------------+
   | Document         | Description                                     |
   +==================+=================================================+
   | `glossary`_      | Python glossary (files, classes, methods).      |
   +------------------+-------------------------------------------------+
   | `logging`_       | Logging configuration and examples.             |
   +------------------+-------------------------------------------------+
   | :doc:`api`       | Auto-generated API reference from docstrings.   |
   +------------------+-------------------------------------------------+
   | :doc:`helpers`   | Build instructions, type aliases, dependencies. |
   +------------------+-------------------------------------------------+
   | :doc:`modules`   | Detailed module and class documentation.        |
   +------------------+-------------------------------------------------+
   | :doc:`reference` | Consolidated function quick-reference.          |
   +------------------+-------------------------------------------------+

.. _glossary: https://pypi.org/project/ut-log/#glossary
.. _logging: https://pypi.org/project/ut-log/#logging


*******
License
*******

``GPL-3.0-only WITH Classpath-Exception-2.0 OR BSD-3-Clause``

Copyright 2025 Bernd Stroehle.


.. toctree::
   :maxdepth: 2
   :hidden:

   readme
   api
   helpers
   modules
   reference


********************
Indices and Tables
********************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
